# RiddhuLib (v0.1.1)

A simple Python addition library made by **Riddhesh Wagvekar**.  
This version includes detailed **comments** and **docstrings** for better readability.

## Installation
```bash
pip install riddhulib
```

## Usage
```python
from riddhulib import add_numbers

add_numbers(10, 5)
```
Output:
```
The sum is: 15
```
